/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.client

import android.content.Context
import com.kakao.sdk.partner.friend.FriendPickerManager
import com.kakao.sdk.partner.friend.model.PickerRequestParams
import com.kakao.sdk.partner.friend.model.SelectedUsers

/**
 * 파트너용으로 제공되는 클래스로, 친구를 선택할 수 있는 친구 선택 화면을 호출합니다.
 */
class PickerClient {

    /**
     * 여러 명의 친구를 선택할 수 있는 친구 선택 화면(멀티 피커)을 화면 전체에 표시합니다.
     */
    fun selectFriends(
        context: Context,
        params: PickerRequestParams,
        callback: (selectedUsers: SelectedUsers?, error: Throwable?) -> Unit
    ) {
        FriendPickerManager().startActivity(context, params, callback)
    }

    /**
     * 한 명의 친구만 선택할 수 있는 친구 선택 화면(싱글 피커)을 화면 전체에 표시합니다.
     */
    fun selectFriend(
        context: Context,
        params: PickerRequestParams,
        callback: (selectedUsers: SelectedUsers?, error: Throwable?) -> Unit
    ) {
        FriendPickerManager(isSingle = true).startActivity(context, params, callback)
    }

    /**
     * 여러 명의 친구를 선택할 수 있는 친구 선택 화면(멀티 피커)을 팝업 형태로 표시합니다.
     */
    fun selectFriendsPopup(
        context: Context,
        params: PickerRequestParams,
        callback: (selectedUsers: SelectedUsers?, error: Throwable?) -> Unit
    ) {
        FriendPickerManager(isPopup = true).startActivity(context, params, callback)
    }

    /**
     * 한 명의 친구만 선택할 수 있는 친구 선택 화면(싱글 피커)을 팝업 형태로 표시합니다.
     */
    fun selectFriendPopup(
        context: Context,
        params: PickerRequestParams,
        callback: (selectedUsers: SelectedUsers?, error: Throwable?) -> Unit
    ) {
        FriendPickerManager(isSingle = true, isPopup = true).startActivity(context, params, callback)
    }

    companion object {
        /**
         * 간편한 API 호출을 위해 기본 제공되는 singleton 객체
         */
        @JvmStatic
        val instance by lazy { PickerClient() }
    }
}